/******************************* REXX *********************************/
/*  REXX Program to act as an extended filter for PMMail/2 2.1.       */
/*  This program will receive two arguments from PMMail/2.  The       */
/*  first is the file name of the E-Mail received from the server.    */
/*  The second is a file in which to place our result.  This program  */
/*  will pass one of two results, either "Send" or "Ignore"           */
/**********************************************************************/
Parse Arg . outfile
 
/**********************************************************************/
/*  These next two lines will get the current day of the week         */
/*  (1=Sunday, 7=Saturday), and the number of minutes since           */
/*  midnight.                                                         */
/**********************************************************************/
dow      = JCDow(JCCalJul(Date('U')))
crnttime = Time('M')
 
/**********************************************************************/
/*  Here's the meat of the logic.  From Monday through Friday,        */
/*  between the hours of 8:00 AM and 5:00 PM (0800 and 1700) we want  */
/*  to pass the value of "Send" back to PMMail/2.  Any other time we  */
/*  want to pass back a value of "Ignore"                             */
/**********************************************************************/
strttime = 8                           /* Start forwarding at 8:00 AM */
endtime  = 17                          /* Stop forwarding at 5:00 PM  */
If dow > 1 & ,
   dow < 7 & ,
   crnttime > (strttime * 60) & ,
   crnttime < (endtime * 60) Then
   Call Lineout outfile, 'Send'
Else
   Call Lineout outfile, 'Ignore'
 
/**********************************************************************/
/*                    All done.  We can end now.                      */
/**********************************************************************/
Exit
